[empathy] tp-account-widgets: refer to the right renamed files



commit cb439fdc95542dc6a918ac16f1d52db7017a7092
Author: Marco Barisione <marco barisione collabora co uk>
Date:   Mon May 13 10:47:00 2013 +0100

    tp-account-widgets: refer to the right renamed files
    
    https://bugzilla.gnome.org/show_bug.cgi?id=699492

 tp-account-widgets/tpaw-account-widget.c     |    8 ++++----
 tp-account-widgets/tpaw-irc-network-dialog.c |    2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/tp-account-widgets/tpaw-irc-network-dialog.c b/tp-account-widgets/tpaw-irc-network-dialog.c
index 502d2ca..0f6b7ce 100644
--- a/tp-account-widgets/tpaw-irc-network-dialog.c
+++ b/tp-account-widgets/tpaw-irc-network-dialog.c
@@ -468,7 +468,7 @@ tpaw_irc_network_dialog_show (TpawIrcNetwork *network,
   dialog->network = network;
   g_object_ref (dialog->network);
 
-  gui = empathy_builder_get_resource (ACCOUNT_WIDGETS_RESOURCES_PREFIX "/empathy-account-widget-irc.ui",
+  gui = empathy_builder_get_resource (ACCOUNT_WIDGETS_RESOURCES_PREFIX "/tpaw-account-widget-irc.ui",
       "irc_network_dialog", &dialog->dialog,
       "button_close", &dialog->button_close,
       "entry_network", &dialog->entry_network,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/tp-account-widgets/tpaw-account-widget.c b/tp-account-widgets/tpaw-account-widget.c
index 7300ea1..c7e9197 100644
--- a/tp-account-widgets/tpaw-account-widget.c
+++ b/tp-account-widgets/tpaw-account-widget.c
@@ -1808,7 +1808,7 @@ out:
 }
 
 #define WIDGET(cm, proto) \
-  { #cm, #proto, ACCOUNT_WIDGETS_RESOURCES_PREFIX "/empathy-account-widget-"#proto".ui", \
+  { #cm, #proto, ACCOUNT_WIDGETS_RESOURCES_PREFIX "/tpaw-account-widget-"#proto".ui", \
     account_widget_build_##proto }
 
 static void
@@ -1904,7 +1904,7 @@ do_constructed (GObject *obj)
     const char *file;
     GtkWidget * (*func)(TpawAccountWidget *self, const gchar *filename);
   } widgets [] = {
-    { "salut", "local-xmpp", ACCOUNT_WIDGETS_RESOURCES_PREFIX "/empathy-account-widget-local-xmpp.ui",
+    { "salut", "local-xmpp", ACCOUNT_WIDGETS_RESOURCES_PREFIX "/tpaw-account-widget-local-xmpp.ui",
         account_widget_build_salut },
     WIDGET (gabble, jabber),
     WIDGET (haze, msn),
@@ -1935,7 +1935,7 @@ do_constructed (GObject *obj)
 
   if (i == G_N_ELEMENTS (widgets))
     {
-      gchar *filename = ACCOUNT_WIDGETS_RESOURCES_PREFIX "/empathy-account-widget-generic.ui";
+      gchar *filename = ACCOUNT_WIDGETS_RESOURCES_PREFIX "/tpaw-account-widget-generic.ui";
       box = account_widget_build_generic (self, filename);
     }
 
@@ -2238,7 +2238,7 @@ tpaw_account_widget_get_default_display_name (TpawAccountWidget *self)
 
   if (login_id != NULL)
     {
       /* TODO: this should be done in empathy-account-widget-irc */
       if (!tp_strdiff (protocol, "irc"))
         {
           TpawIrcNetwork *network;
@@ -2238,7 +2238,7 @@ tpaw_account_widget_get_default_display_name (TpawAccountWidget *self)
   if (login_id != NULL)
     {
-      /* TODO: this should be done in empathy-account-widget-irc */
+      /* TODO: this should be done in tpaw-account-widget-irc */
       if (!tp_strdiff (protocol, "irc"))
         {